M3Year: M3-Competition yearly data

Description Usage Format Author(s) Source See Also Examples

Description

The yearly time series from the M3 forecasting competition.

Usage

1

Format

M3 is a list of 2 data.frames of 645 yearly time series from M3-Competition.

First list element is the data.frame with the following structure:

series

Name of the series

category

The category of series. Possible values for M3 are "DEMOGRAPHIC", "FINANCE", "INDUSTRY", "MACRO", "MICRO", "OTHER".

value

A time series (the historical data(training data) + the future data (test data))

timesatmp

The timestamp of series (yearly period)

Second list element is the data.frame with the following structure:

serie

Name of the series

category

The category of series. Possible values for M3 are "DEMOGRAPHIC", "FINANCE", "INDUSTRY", "MACRO", "MICRO", "OTHER".

actual

The future data (test data) or actual values of each time series from M3-Competition yearly data

method

The forecasting methods for each time series from M3-Competition yearly data

forecast

The forecast values obtained from difference forecasting methods for each time series from M3-Competition yearly data

horizon

The forecast horizons for each time series from M3-Competition yearly data

timesatmp

The timestamp of series (yearly period)

Author(s)

Andrey Davydenko, Maxim and Sai Van Cuong from Volgograd State Technical University

https://github.com/svcuonghvktqs/M3FORA.

See Also

plot.ts

Examples

1
2
3
4
5
M3Year[[1]][1:5,]
M3Year[[2]][1:5,]
subset(M3Year[[1]], series == "Y1")
subset(M3Year[[2]], method == "HOLT")
plot.ts(M3Year, series_id = "Y1")

svcuonghvktqs/M3FORA documentation built on May 30, 2019, 8:27 a.m.