Description Usage Format Author(s) Source See Also Examples
The yearly time series from the M3 forecasting competition.
1 |
M3 is a list of 2 data.frames of 645 yearly time series from M3-Competition.
First list element is the data.frame with the following structure:
Name of the series
The category of series. Possible values for M3 are "DEMOGRAPHIC", "FINANCE", "INDUSTRY", "MACRO", "MICRO", "OTHER".
A time series (the historical data(training data) + the future data (test data))
The timestamp of series (yearly period)
Second list element is the data.frame with the following structure:
Name of the series
The category of series. Possible values for M3 are "DEMOGRAPHIC", "FINANCE", "INDUSTRY", "MACRO", "MICRO", "OTHER".
The future data (test data) or actual values of each time series from M3-Competition yearly data
The forecasting methods for each time series from M3-Competition yearly data
The forecast values obtained from difference forecasting methods for each time series from M3-Competition yearly data
The forecast horizons for each time series from M3-Competition yearly data
The timestamp of series (yearly period)
Andrey Davydenko, Maxim and Sai Van Cuong from Volgograd State Technical University
https://github.com/svcuonghvktqs/M3FORA.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.